JsonStringCodec

com.digitalasset.transcode.codec.json.JsonStringCodec
class JsonStringCodec(encodeNumericAsString: Boolean, encodeInt64AsString: Boolean, removeTrailingNonesInRecords: Boolean) extends Delegate[JsonCodec, Dictionary[Codec[String]]]

Attributes

Graph
Supertypes
trait Delegate[JsonCodec, Dictionary[Codec[String]]]
trait WithResult[Dictionary[Codec[String]]]
class Object
trait Matchable
class Any
Show all

Members list

Type members

Inherited types

final type Result = Dictionary[Codec[String]]

Final result type

Final result type

Attributes

Inherited from:
WithResult
type Type = this.delegate.Type

Visitor handler type for various DAML schema cases.

Visitor handler type for various DAML schema cases.

Attributes

Inherited from:
Delegate

Value members

Inherited methods

Type Application

Type Application

Attributes

Inherited from:
Delegate
def bool: Type

Boolean

Boolean

Attributes

Inherited from:
Delegate
final def collect(entities: Seq[Template[delegate.Type]]): Dictionary[Codec[String]]

Attributes

Inherited from:
Delegate

Wrap type into addressable DataType

Wrap type into addressable DataType

Attributes

Inherited from:
Delegate

Contract ID, parametrized with the processor for corresponding template

Contract ID, parametrized with the processor for corresponding template

Attributes

Inherited from:
Delegate
def date: Type

Date

Date

Attributes

Inherited from:
Delegate

ADT, Sum type - special case, where there are only named constructors without arguments

ADT, Sum type - special case, where there are only named constructors without arguments

Attributes

Inherited from:
Delegate

Map with keys and values of any type

Map with keys and values of any type

Attributes

Inherited from:
Delegate
def int64: Type

8-byte Integer

8-byte Integer

Attributes

Inherited from:
Delegate
def list(elem: Type): Type

Sequence of elements

Sequence of elements

Attributes

Inherited from:
Delegate

Numeric with scale

Numeric with scale

Attributes

Inherited from:
Delegate

Optional element

Optional element

Attributes

Inherited from:
Delegate
def party: Type

Party

Party

Attributes

Inherited from:
Delegate

ADT, Product type

ADT, Product type

Attributes

Inherited from:
Delegate
def text: Type

Text

Text

Attributes

Inherited from:
Delegate

Map with keys of String/Text type

Map with keys of String/Text type

Attributes

Inherited from:
Delegate

Timestamp

Timestamp

Attributes

Inherited from:
Delegate
def unit: Type

Unit

Unit

Attributes

Inherited from:
Delegate

Unknown Type. A template can reference ContractId U where U is unknown because non-serializable. This type cannot be used for decoding payloads.

Unknown Type. A template can reference ContractId U where U is unknown because non-serializable. This type cannot be used for decoding payloads.

Value parameters

args

The type arguments or empty if id is not a type constructor. This cannot be modeled as an application because the type param names are unknown.

id

The type or type constructor identifier

Attributes

Inherited from:
Delegate

Type Variable.

Type Variable.

Codecs will use substitution, effectively replacing type variables with concrete types, while code generators will use type variable names.

Attributes

Inherited from:
Delegate

ADT, Sum type

ADT, Sum type

Attributes

Inherited from:
Delegate

Inherited fields

protected val conv: delegate.Result => Dictionary[Codec[String]]

Attributes

Inherited from:
Delegate
protected val delegate: JsonCodec

Attributes

Inherited from:
Delegate