com.digitalasset.transcode.codec.json
Members list
Type members
Classlikes
Json Codec.
Json Codec.
Value parameters
- allowMissingFields
-
allow missing fields in records or throw, Canton uses this for testing only
- encodeInt64AsString
-
encode int64 as a string (true) or as a json number (false). The latter might be useful for querying and mathematical operations, but can lose precision, as numbers in some json implementations are backed Double.
- encodeNumericAsString
-
encode numeric as string (true) or as a json number (false). The latter might be useful for querying and mathematical operations, but can lose precision due to float point errors.
- removeTrailingNonesInRecords
-
if true, trailing nones are removed from the record values
Attributes
- Supertypes
class JsonStringCodec(encodeNumericAsString: Boolean, encodeInt64AsString: Boolean, removeTrailingNonesInRecords: Boolean) extends Delegate[JsonCodec, Dictionary[Codec[String]]]
Attributes
- Supertypes
In this article