JsonCodec
Json Codec.
Value parameters
- allowMissingFields
-
allow missing fields in records or throw, Canton uses this for testing only
- encodeInt64AsString
-
encode int64 as a string (true) or as a json number (false). The latter might be useful for querying and mathematical operations, but can lose precision, as numbers in some json implementations are backed Double.
- encodeNumericAsString
-
encode numeric as string (true) or as a json number (false). The latter might be useful for querying and mathematical operations, but can lose precision due to float point errors.
- removeTrailingNonesInRecords
-
if true, trailing nones are removed from the record values
Attributes
- Graph
-
- Supertypes
Members list
Type members
Inherited types
Final result type
Visitor handler type for various DAML schema cases.
Value members
Concrete methods
Boolean
Contract ID, parametrized with the processor for corresponding template
Contract ID, parametrized with the processor for corresponding template
Attributes
- Definition Classes
Date
ADT, Sum type - special case, where there are only named constructors without arguments
ADT, Sum type - special case, where there are only named constructors without arguments
Attributes
- Definition Classes
Map with keys and values of any type
8-byte Integer
Sequence of elements
Numeric with scale
Optional element
Party
ADT, Product type
Text
Map with keys of String/Text type
Timestamp
Unit
ADT, Sum type
Inherited methods
Type Application
Attributes
- Definition Classes
- Inherited from:
- CodecVisitor
Wrap type into addressable DataType
Unknown Type. A template can reference ContractId U where U is unknown because non-serializable. This type cannot be used for decoding payloads.
Unknown Type. A template can reference ContractId U where U is unknown because non-serializable. This type cannot be used for decoding payloads.
Value parameters
- args
-
The type arguments or empty if id is not a type constructor. This cannot be modeled as an application because the type param names are unknown.
- id
-
The type or type constructor identifier
Attributes
- Definition Classes
- Inherited from:
- CodecVisitor
Type Variable.
Type Variable.
Codecs will use substitution, effectively replacing type variables with concrete types, while code generators will use type variable names.
Attributes
- Definition Classes
- Inherited from:
- CodecVisitor