JsonStringCodec
Attributes
- Graph
-
- Supertypes
Members list
Type members
Inherited types
Final result type
Value members
Inherited methods
Type Application
Attributes
- Inherited from:
- Delegate
Wrap type into addressable DataType
Contract ID, parametrized with the processor for corresponding template
Contract ID, parametrized with the processor for corresponding template
Attributes
- Inherited from:
- Delegate
ADT, Sum type - special case, where there are only named constructors without arguments
ADT, Sum type - special case, where there are only named constructors without arguments
Attributes
- Inherited from:
- Delegate
Map with keys and values of any type
Sequence of elements
Numeric with scale
Optional element
ADT, Product type
Map with keys of String/Text type
Unknown Type. A template can reference ContractId U where U is unknown because non-serializable. This type cannot be used for decoding payloads.
Unknown Type. A template can reference ContractId U where U is unknown because non-serializable. This type cannot be used for decoding payloads.
Value parameters
- args
-
The type arguments or empty if id is not a type constructor. This cannot be modeled as an application because the type param names are unknown.
- id
-
The type or type constructor identifier
Attributes
- Inherited from:
- Delegate
Type Variable.
Type Variable.
Codecs will use substitution, effectively replacing type variables with concrete types, while code generators will use type variable names.
Attributes
- Inherited from:
- Delegate